OC.L10N.register(
    "files",
    {
    "File could not be found" : "Fil kunde inte hittas",
    "Move or copy" : "Flytta eller kopiera",
    "Download" : "Hämta",
    "Delete" : "Radera",
    "Tags" : "Taggar",
    "Show list view" : "Visa listvy",
    "Show grid view" : "Visa rutnätsvy",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "This will stop your current uploads." : "Detta kommer att stoppa nuvarande uppladdningar.",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Processing files …" : "Bearbetar filer ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Target folder \"{dir}\" does not exist any more" : "Målmapp \"{dir}\" existerar inte mer",
    "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
    "An unknown error has occurred" : "Ett okänt fel uppstod",
    "File could not be uploaded" : "Filen kunde inte laddas upp",
    "Uploading …" : "Laddar upp ..",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Laddar upp … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uppladdning av det här objektet stöds inte",
    "Target folder does not exist any more" : "Målmapp existerar inte längre",
    "Operation is blocked by access control" : "Operationen blockeras av åtkomstkontroll",
    "Error when assembling chunks, status code {status}" : "Fel vid ihopsättning av bitarna: statuskod:  {status}",
    "Actions" : "Funktioner",
    "Rename" : "Byt namn",
    "Move" : "Flytta",
    "Copy" : "Kopiera",
    "Choose target folder" : "Välj målmapp",
    "Set reminder" : "Ställ in påminnelse",
    "Edit locally" : "Redigera lokalt",
    "Open" : "Öppna",
    "Delete file" : "Ta bort fil",
    "Delete folder" : "Ta bort mapp",
    "Disconnect storage" : "Koppla bort lagring",
    "Leave this share" : "Lämna denna delning",
    "Could not load info for file \"{file}\"" : "Kunde inte läsa in information för filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Please select tag(s) to add to the selection" : "Vänligen välj tagg(ar) att lägga till i ditt urval",
    "Apply tag(s) to selection" : "Lägg till tagg(ar) i ditt urval",
    "Select directory \"{dirName}\"" : "Välj mapp \"{dirName}\"",
    "Select file \"{fileName}\"" : "Välj fil \"{fileName}\"",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Storage is temporarily not available" : "Lagring är tillfälligt inte tillgänglig",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "copy" : "kopia",
    "Could not copy \"{file}\", target exists" : "Kunde inte kopiera \"{file}\", filen existerar redan",
    "Could not copy \"{file}\"" : "Kunde inte kopiera \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierade {origin} till {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierade {origin} och {nbfiles} andra filer i {destination}",
    "Failed to redirect to client" : "Det gick inte att omdirigera till klienten",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Could not fetch file details \"{file}\"" : "Kunde inte hämta filinformation \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Inga sökresultat i andra mappar för {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Ange mer än två tecken för att söka i andra mappar",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkluderar %n dold","inkluderar %n dolda"],
    "You do not have permission to upload or create files here" : "Du har inte behörighet att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "New file/folder menu" : "Ny fil/mapp -meny",
    "Select file range" : "Välj filintervall",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} av {quota} använt",
    "{used} used" : "{used} använt",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltigt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" är inte tillåtet i ett filnamn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Gruppmapp \"{mountPoint}\" är full, filer kan inte uppdateras eller synkroniseras längre!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Extern lagring \"{mountPoint}\" är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Gruppmapp \"{mountPoint}\" är nästan full ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Extern lagring \"{mountPoint}\" är nästan full ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["matcha \"{filter}\"","matcha \"{filter}\""],
    "View in folder" : "Utforska i mapp",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Direktlänk kopierades (fungerar endast för användare som har tillgång till denna fil/mapp)",
    "Path" : "Sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoriserad",
    "Favorite" : "Favorit",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för användare som har åtkomst till denna fil eller mapp)",
    "New folder" : "Ny mapp",
    "Create new folder" : "Skapa ny mapp",
    "Upload file" : "Ladda upp fil",
    "Recent" : "Senaste",
    "Not favorited" : "Inte favoriserade",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till i favoriter",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "Added to favorites" : "Lades till i favoriter",
    "Removed from favorites" : "Togs bort från favoriter",
    "You added {file} to your favorites" : "Du la till {file} till dina favoriter",
    "You removed {file} from your favorites" : "Du tog bort {file} från dina favoriter",
    "Favorites" : "Favoriter",
    "File changes" : "Filändringar",
    "Created by {user}" : "Skapad av {user}",
    "Changed by {user}" : "Ändrad av {user}",
    "Deleted by {user}" : "Raderad av {user}",
    "Restored by {user}" : "Återställd av {user}",
    "Renamed by {user}" : "Filnamn ändrat av {user}",
    "Moved by {user}" : "Flyttad av {user}",
    "\"remote user\"" : "\"extern användare\"",
    "You created {file}" : "Du skapade {file}",
    "You created an encrypted file in {file}" : "Du skapade en krypterad fil i {file}",
    "{user} created {file}" : "{user} skapade {file}",
    "{user} created an encrypted file in {file}" : "{user} skapade en krypterad fil i {file}",
    "{file} was created in a public folder" : "{file} skapades i en offentlig mapp",
    "You changed {file}" : "Du ändrade {file}",
    "You changed an encrypted file in {file}" : "Du ändrade en krypterad fil i {file}",
    "{user} changed {file}" : "{user} ändrade {file}",
    "{user} changed an encrypted file in {file}" : "{user} ändrade en krypterad fil i {file}",
    "You deleted {file}" : "Du raderade {file}",
    "You deleted an encrypted file in {file}" : "Du tog bort en krypterad fil i {file}",
    "{user} deleted {file}" : "{user} raderade {file}",
    "{user} deleted an encrypted file in {file}" : "{user} tog bort en krypterad fil i {file}",
    "You restored {file}" : "Du återställde {file}",
    "{user} restored {file}" : "{user} återställde {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Du ändrade filnamn {oldfile} (dold) till {newfile} (dold)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Du ändrade filnamn {oldfile} (dold) till {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Du ändrade filnamn {oldfile} till {newfile} (dold)",
    "You renamed {oldfile} to {newfile}" : "Du ändrade filnamn {oldfile} till {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} ändrade filnamn {oldfile} (dold) till {newfile} (dold)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} ändrade filnamn {oldfile} (dold) till {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} ändrade filnamn {oldfile} till {newfile} (dold)",
    "{user} renamed {oldfile} to {newfile}" : "{user} ändrade filnamn {oldfile} till {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttade {oldfile} till {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttade {oldfile} till {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har lagts till eller tagits bort från dina <strong>favoriter</strong>",
    "A file or folder has been <strong>changed</strong>" : "En ny fil eller mapp har blivit <strong>ändrad</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "En favorit-fil eller mapp har blivit <strong>ändrad</strong>",
    "Upload (max. %s)" : "Ladda upp (högst %s)",
    "Accept" : "Acceptera",
    "Reject" : "Avvisa",
    "Incoming ownership transfer from {user}" : "Inkommande ägaröverföring från {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Vill du acceptera {path}?\n\nNotera: Överföringen kan efter att du accepterat ta upp till 1 timme.",
    "Ownership transfer failed" : "Ägarskapsöverföring misslyckades",
    "Your ownership transfer of {path} to {user} failed." : "Din ägaröverföring av {path} till {user} misslyckades.",
    "The ownership transfer of {path} from {user} failed." : "Din ägaröverföring av {path} från {user} misslyckades.",
    "Ownership transfer done" : "Ägarskapsöverföring klar",
    "Your ownership transfer of {path} to {user} has completed." : "Din ägaröverföring av {path} till {user} är klar.",
    "The ownership transfer of {path} from {user} has completed." : "Ägaröverföringen av {path} från {user} är klar.",
    "in %s" : "om %s",
    "File Management" : "Filhantering",
    "Current directory path" : "Aktuell katalogsökväg",
    "Reload current directory" : "Ladda om nuvarande mapp",
    "Go to the \"{dir}\" directory" : "Gå till \"{dir}\" mappen",
    "Drag and drop files here to upload" : "Dra och släpp filer här för att ladda upp",
    "Your have used your space quota and cannot upload files anymore" : "Du har använt din utrymmeskvot och kan inte längre ladda upp filer",
    "You don’t have permission to upload or create files here" : "Du har inte tillåtelse att ladda upp eller skapa filer här",
    "Upload successful" : "Uppladdningen lyckades",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\"-åtgärden har utförts",
    "\"{displayName}\" action failed" : "\"{displayName}\"-åtgärden misslyckades",
    "Toggle selection for file \"{displayName}\"" : "Växla markering för filen \"{displayName}\"",
    "Toggle selection for folder \"{displayName}\"" : "Växla markering för mappen \"{displayName}\"",
    "Rename file" : "Byt namn på fil",
    "File name" : "Filnamn",
    "Folder name" : "Mappnamn",
    "This node is unavailable" : "Den här noden är inte tillgänglig",
    "Download file {name}" : "Ladda ner filen {name}",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" är inte en tillåten filtyp.",
    "{newName} already exists." : "{newName} finns redan.",
    "\"{char}\" is not allowed inside a file name." : "\"{char}\" är inte tillåtet i ett filnamn.",
    "Name cannot be empty" : "Namn kan inte vara tom",
    "Another entry with the same name already exists" : "En annan post med samma namn finns redan",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Bytte namn på \"{oldName}\" till \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Kunde inte byta namn på \"{oldName}\", den finns inte längre",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{newName}\" används redan i mappen \"{dir}\". Välj ett annat namn.",
    "Could not rename \"{oldName}\"" : "Kunde inte byta namn på \"{oldName}\"",
    "Could not copy {file}. {message}" : "Kunde inte kopiera {file}. {message}",
    "Could not move {file}. {message}" : "Kunde inte flytta {file}. {message}",
    "Total rows summary" : "Sammanfattning antal rader",
    "Toggle selection for all files and folders" : "Växla markering för alla filer och mappar",
    "\"{displayName}\" failed on some elements " : "\"{displayName}\" misslyckades med vissa element",
    "\"{displayName}\" batch action executed successfully" : "Batchåtgärden \"{displayName}\" har utförts",
    "List of files and folders." : "Lista över filer och mappar.",
    "Column headers with buttons are sortable." : "Kolumnrubriker med knappar är sorterbara.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
    "File not found" : "Filen kunde inte hittas",
    "Storage informations" : "Lagringsinformation",
    "{usedQuotaByte} used" : "{usedQuotaByte} använt",
    "{relative}% used" : "{relative}% använt",
    "Could not refresh storage stats" : "Det gick inte att uppdatera lagringsstatistiken",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Transfer ownership of a file or folder" : "Överför ägarskap av en fil eller mapp",
    "Choose file or folder to transfer" : "Välj fil eller mapp att överföra",
    "Change" : "Ändra",
    "New owner" : "Ny ägare",
    "Choose a file or folder to transfer" : "Välj en fil eller mapp att överföra",
    "Transfer" : "Överför",
    "Transfer {path} to {userid}" : "Överför {path} till {userid}",
    "Invalid path selected" : "Ogiltig sökväg vald",
    "Unknown error" : "Okänt fel",
    "Ownership transfer request sent" : "Förfrågan om ägaröverföring skickad",
    "Cannot transfer ownership of a file or folder you do not own" : "Det går inte att överföra äganderätten till en fil eller mapp som du inte äger",
    "Select file or folder to link to" : "Välj fil eller mapp att länka till",
    "Choose file" : "Välj fil",
    "Choose {file}" : "Välj {file}",
    "Add" : "Lägg till",
    "Loading current folder" : "Laddar aktuell mapp",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "Go to the previous folder" : "Gå till föregående mapp",
    "Go back" : "Gå tillbaks",
    "Share" : "Dela",
    "Shared by link" : "Delad via länk",
    "Shared" : "Delad",
    "Switch to list view" : "Växla till listvy",
    "Switch to grid view" : "Växla till rutnätsvy",
    "Error during upload: {message}" : "Fel vid uppladdning: {message}",
    "Error during upload, status code {status}" : "Fel vid uppladdning, statuskod {status}",
    "Unknown error during upload" : "Okänt fel under uppladdning",
    "Open the files app settings" : "Öppna filappens inställningar",
    "Files settings" : "Filinställningar",
    "File cannot be accessed" : "Det går inte att komma åt filen",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Filen kunde inte hittas eller så har du inte behörighet att visa den. Be avsändaren att dela den.",
    "Sort favorites first" : "Sortera favoriter först",
    "Sort folders before files" : "Sortera mappar före filer",
    "Show hidden files" : "Visa dolda filer",
    "Crop image previews" : "Beskär förhandsgranskningar för bilder",
    "Enable the grid view" : "Aktivera rutnätsvy",
    "Additional settings" : "Övriga inställningar",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Kopiera till urklipp",
    "Use this address to access your Files via WebDAV" : "Använd denna adress för att komma åt dina filer med WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Om du har aktiverat 2FA måste du skapa och använda ett nytt applösenord genom att klicka här.",
    "Clipboard is not available" : "Urklipp är inte tillgängligt",
    "WebDAV URL copied to clipboard" : "WebDAV URL kopierad till urklipp",
    "Unable to change the favourite state of the file" : "Kan inte ändra filens favoritstatus",
    "Error while loading the file data" : "Fel vid inläsning av fildata",
    "Pick a template for {name}" : "Välj en mall för {name}",
    "Create" : "Skapa",
    "Create a new file with the selected template" : "Skapa en ny fil med den valda mallen",
    "Creating file" : "Skapar fil",
    "Blank" : "Tom",
    "Unable to create new file from template" : "Kunde inte skapa fil från mall",
    "Delete permanently" : "Ta bort permanent",
    "Destination is not a folder" : "Destinationen är inte en mapp",
    "This file/folder is already in that directory" : "Den här filen/mappen finns redan i den katalogen",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Du kan inte flytta en fil/mapp till sig själv eller till en undermapp till sig själv",
    "(copy)" : "(kopia)",
    "(copy %n)" : "(kopia %n)",
    "A file or folder with that name already exists in this folder" : "En fil eller mapp med det namnet finns redan i den här mappen",
    "The files is locked" : "Filerna är låsta",
    "The file does not exist anymore" : "Filen finns inte längre",
    "Choose destination" : "Välj destination",
    "Copy to {target}" : "Kopiera till {target}",
    "Move to {target}" : "Flytta till {target}",
    "Cancelled move or copy operation" : "Flytta eller kopiera avbröts",
    "Move or copy operation failed" : "Flytta eller kopiera misslyckades",
    "Open folder {displayName}" : "Öppna mappen {displayName}",
    "Open in Files" : "Öppna i Filer",
    "Open details" : "Öppna detaljer",
    "Create new templates folder" : "Skapa ny mallmapp",
    "Templates" : "Mallar",
    "Unable to initialize the templates directory" : "Kunde inte initialisera mall-mappen",
    "Created new folder \"{name}\"" : "Skapat ny mapp \"{name}\"",
    "One of the dropped files could not be processed" : "En av de släppta filerna kunde inte bearbetas",
    "Uploading \"{filename}\" failed" : "Uppladdning av \"{filename}\" misslyckades",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} mapp","{folderCount} mappar"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fil","{fileCount} filer"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fil och {folderCount} mapp","1 fil och {folderCount} mappar"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fil och 1 mapp","{fileCount} filer och 1 mapp"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} filer och {folderCount} mappar",
    "List of favorites files and folders." : "Lista över favoritfiler och mappar.",
    "No favorites yet" : "Inga favoriter ännu",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
    "All files" : "Alla filer",
    "List of your files and folders." : "Lista över dina filer och mappar.",
    "List of recently modified files and folders." : "Lista över nyligen ändrade filer och mappar.",
    "No recently modified files" : "Inga nyligen ändrade filer",
    "Files and folders you recently modified will show up here." : "Filer och mappar som du nyligen ändrat kommer att visas här.",
    "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "Text file" : "Textfil",
    "New text file.txt" : "Ny textfil.txt",
    "You can only favorite a single file or folder at a time" : "Du kan bara favoritmarkera en fil eller mapp åt gången",
    "Search users" : "Sök användare",
    "You might not have have permissions to view it, ask the sender to share it" : "Du kanske inte har behörighet att se den, be avsändaren att dela den",
    "Cancel" : "Avbryt",
    "Set up templates folder" : "Skapa en mapp för mallar",
    "Toggle %1$s sublist" : "Växla %1$s sublista",
    "Toggle grid view" : "Växla rutnätsvy",
    "Deleted files" : "Borttagna filer",
    "Shares" : "Delningar",
    "Shared with others" : "Delas med andra",
    "Shared with you" : "Delas med mig",
    "Deleted shares" : "Borttagna delningar",
    "Pending shares" : "Väntande delningar",
    "This file has the tag {tag}" : "Den här filen har taggen {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Den här filen har taggarna {firstTags} och {lastTag}",
    "Select the row for {displayName}" : "Välj raden för {displayName}",
    "Open folder {name}" : "Öppna mappen {name}",
    "Unselect all" : "Avmarkera alla",
    "ascending" : "stigande",
    "descending" : "fallande",
    "Sort list by {column} ({direction})" : "Sortera listan efter {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Denna lista är inte helt återgiven av prestandaskäl. Filerna kommer att renderas när du navigerar genom listan.",
    "Search for an account" : "Sök efter ett konto",
    "Choose" : "Välj",
    "No files or folders have been deleted yet" : "Inga filer eller mappar har tagits bort än"
},
"nplurals=2; plural=(n != 1);");
